@@ -1,12 +1,12 @@
 ######################################################################
 # autometarobot.inc.cgi - This is PyukiWiki, yet another Wiki clone.
-# $Id: autometarobot.inc.pl,v 1.51 2007/07/15 07:40:09 papu Exp $
+# $Id: autometarobot.inc.pl,v 1.84 2011/05/04 07:26:50 papu Exp $
 #
-# "PyukiWiki" version 0.1.7 $$
-# Author: Nanami http://lineage.netgamers.jp/
-# Copyright (C) 2004-2007 by Nekyo.
-# http://nekyo.hp.infoseek.co.jp/
-# Copyright (C) 2005-2007 PyukiWiki Developers Team
+# "PyukiWiki" version 0.1.9 $$
+# Author: Nanami http://nanakochi.daiba.cx/
+# Copyright (C) 2004-2011 by Nekyo.
+# http://nekyo.qp.land.to/
+# Copyright (C) 2005-2011 PyukiWiki Developers Team
 # http://pyukiwiki.sourceforge.jp/
 # Based on YukiWiki http://www.hyuki.com/yukiwiki/
 # Powerd by PukiWiki http://pukiwiki.sourceforge.jp/
@@ -22,6 +22,11 @@
 #
 # ڡܥåȷ󥸥ؤΥɤư
 #
+# 
+# ɤޤˤ⹥ߤǤʤΤǤС
+# ŬwikiΤζĴʸꤷƤߤꡢƤߤ
+# ƤߤƲ
+#
 ######################################################################
 
 $::auto_meta_maxkeyword=100								# ưɤñ
@@ -58,12 +63,13 @@ EOD
 		if($::auto_meta_maxkeyword>0) {
 			# ʲɼư
 			my @keyword;
-			$keyword="$::wiki_title," . &htmlspecialchars($pagename);
+			$keyword="$::wiki_title," . &htmlspecialchars($pagename) . ",";
+#			$keyword="$::wiki_title," . &htmlspecialchars($pagename);
 			# <h?></h?>ĴWikiName
 			foreach($body=~/(<h\d>(.+?)<\/h\d>|<strong>(.+?)<\/strong>|$::wiki_name)/g) {
 				s/[\x0d\x0a]//g;
 				s/<.*?>//g;
-				$keyword.="$_ ,";
+				$keyword.="$_,";
 			}
 			# img alt="", a title=""
 			foreach($body=~/<(?:a|img)(?:.+?)(?:alt|title)="(.+?)"(?:.+)>/g) {
@@ -71,7 +77,7 @@ EOD
 				s/[\x0d\x0a]//g;
 				s/<.*?>//g;
 				next if(/$::resource{editthispage}|$::resource{admineditthispage}/);
-				$keyword.="$_ ";
+				$keyword.="$_,";
 			}
 			$keyword=~s/$::_symbol_anchor//g;
 			$keyword=~s/([\x0-\x2f|\x3a-\x40|\x5b-\x60|\x7b-\x7f]|(?:\xA1\xA1))/,/g;
@@ -89,7 +95,7 @@ EOD
 			$keyword="";
 			my $i=0;
 			foreach(@keyword) {
-				unless($keyword=~/$_/) {
+				unless($keyword=~/\,$_/) {
 					$keyword.="$_,";
 					last if(++$i >= $::auto_meta_maxkeyword);
 				}
@@ -140,7 +146,7 @@ L<http://pyukiwiki.sourceforge.jp/PyukiWiki/Plugin/ExPlugin/autometarobot/>
 
 =item PyukiWiki CVS
 
-L<http://cvs.sourceforge.jp/cgi-bin/viewcvs.cgi/pyukiwiki/PyukiWiki-Devel/lib/autometarobot.inc.pl>
+L<http://sourceforge.jp/cvs/view/pyukiwiki/PyukiWiki-Devel/lib/autometarobot.inc.pl?view=log>
 
 =back
 
@@ -150,17 +156,19 @@ L<http://cvs.sourceforge.jp/cgi-bin/viewcvs.cgi/pyukiwiki/PyukiWiki-Devel/lib/au
 
 =item Nanami
 
-L<http://lineage.netgamers.jp/> etc...
+L<http://nanakochi.daiba.cx/> etc...
 
 =item PyukiWiki Developers Team
 
 L<http://pyukiwiki.sourceforge.jp/>
 
+=back
+
 =head1 LICENSE
 
-Copyright (C) 2005-2007 by Nanami.
+Copyright (C) 2005-2011 by Nanami.
 
-Copyright (C) 2005-2007 by PyukiWiki Developers Team
+Copyright (C) 2005-2011 by PyukiWiki Developers Team
 
 License is GNU GENERAL PUBLIC LICENSE 2 and/or Artistic 1 or each later version.
 
