@@ -1,12 +1,12 @@
 ######################################################################
 # calendar2.inc.pl - This is PyukiWiki, yet another Wiki clone.
-# $Id: calendar2.inc.pl,v 1.42 2006/03/17 14:00:10 papu Exp $
+# $Id: calendar2.inc.pl,v 1.84 2011/05/04 07:26:50 papu Exp $
 #
-# "PyukiWiki" version 0.1.6 $$
-# Author: Nanami http://lineage.netgamers.jp/
-# Copyright (C) 2004-2006 by Nekyo.
-# http://nekyo.hp.infoseek.co.jp/
-# Copyright (C) 2005-2006 PyukiWiki Developers Team
+# "PyukiWiki" version 0.1.9 $$
+# Author: Nanami http://nanakochi.daiba.cx/
+# Copyright (C) 2004-2011 by Nekyo.
+# http://nekyo.qp.land.to/
+# Copyright (C) 2005-2011 PyukiWiki Developers Team
 # http://pyukiwiki.sourceforge.jp/
 # Based on YukiWiki http://www.hyuki.com/yukiwiki/
 # Powerd by PukiWiki http://pukiwiki.sourceforge.jp/
@@ -19,11 +19,7 @@
 # Բ̤ΰ١ȤƤޤ󤬡صξ
 # v0.1.6бǤۤ뤳ȤȤޤ
 # ʤ굡ǽ夷ƤƽŤʤäƤޤΤǡڲʤۤѤ
-# ϡꥸʥǤѲ
-# http://hpcgi1.nifty.com/it2f/wikinger/pyukiwiki.cgi?PyukiWiki%2f%a5%d7%a5%e9%a5%b0%a5%a4%a5%f3%2fcalendar
-#
-# calendar_viewerϡʲΤѲ(ȤȻפޤ
-# http://hpcgi1.nifty.com/it2f/wikinger/pyukiwiki.cgi?cmd=attach&pcmd=open&file=calendar_viewer%2einc%2epl&mypage=PyukiWiki%2f%a5%d7%a5%e9%a5%b0%a5%a4%a5%f3%2fcalendar&refer=%c6%fc%b5%ad%2f2004%2d11%2d02
+# ϡꥸʥǤcalender.inc.plѲ
 #
 # 䤷ˤɤΤȤϰʲǰۤʤޤ
 # ɥ١˽񤭴
@@ -57,18 +53,20 @@ use Time::Local;
 
 ######################################################################
 # Խ̤Ǥν
-
+# ALT
 
 if($::_exec_plugined{exdate} ne '') {
 	# exdateƳƤ ( ) Ѥʸ
 	$calendar2::initwikiformat=<<EOM;
 *&date(SGGYǯZnZjDLRY RK RS RG XG SZ MG,__DATE__);
 EOM
+	$calendar2::altformat="DL RY RK RG";
 } else {
 	# exdateƳƤʤ
 	$calendar2::initwikiformat=<<EOM;
 *&date(Y-n-j[lL],__DATE__);
 EOM
+	$calendar2::altformat="[lL]";
 }
 
 ######################################################################
@@ -188,13 +186,16 @@ END
 		} else {
 			$style = 'style_td_day';
 		}
-		my $alt=&date($date_format,
+		my $alt=&date($calendar2::altformat,
 			Time::Local::timelocal(0,0,0,$i,$disp_month-1,$disp_year-1900));
-		$alt=~s/\n\n/\n/g while($alt=~/\n\n/);
-		$alt=~s/(\xA1\xA1| )(\xA1\xA1| )/$1/g if($alt=~/(\xA1\xA1| )/);
-		$alt=~s/(\xA1\xA1| )\n/\n/g while($alt=~/(\xA1\xA1| )\n/);
-		$alt=~s/\n(\xA1\xA1| )/\n/g while($alt=~/\n(\xA1\xA1| )/);
-		$alt=~s/\n/$crlf/g while($alt=~/\n/);
+#		$alt=~s/\n\n/\n/g while($alt=~/\n\n/);
+#		$alt=~s/(\xA1\xA1| )(\xA1\xA1| )/$1/g if($alt=~/(\xA1\xA1| )/);
+#		$alt=~s/(\xA1\xA1| )\n/\n/g while($alt=~/(\xA1\xA1| )\n/);
+#		$alt=~s/\n(\xA1\xA1| )/\n/g while($alt=~/\n(\xA1\xA1| )/);
+#		$alt=~s/\n/$crlf/g while($alt=~/\n/);
+		$alt=~s/^\s//g while($alt=~/^\s/);
+		$alt=~s/\s\s/ /g while($alt=~/\s\s/);
+		$alt=~s/\s$//g while($alt=~/\s$/);
 		$calendar .= qq(<td class="$style">@{[&makepagelink($pagename,"$alt","$alt",$i,$initwiki_format,"$disp_year/$disp_month/$i")]}</td>);
 	}
 	$disp_wday=&getwday($disp_year,$disp_month,&lastday($disp_year,$disp_month));
@@ -330,9 +331,13 @@ Date format samples
 
 L<http://pyukiwiki.sourceforge.jp/PyukiWiki/Plugin/Standard/calendar2/>
 
+=item PyukiWiki/Plugin/Standard/calendar
+
+L<http://pyukiwiki.sourceforge.jp/PyukiWiki/Plugin/Standard/calendar/>
+
 =item PyukiWiki CVS
 
-L<http://cvs.sourceforge.jp/cgi-bin/viewcvs.cgi/pyukiwiki/PyukiWiki-Devel/plugin/calendar2.inc.pl>
+L<http://sourceforge.jp/cvs/view/pyukiwiki/PyukiWiki-Devel/plugin/calendar2.inc.pl?view=log>
 
 =back
 
@@ -342,7 +347,7 @@ L<http://cvs.sourceforge.jp/cgi-bin/viewcvs.cgi/pyukiwiki/PyukiWiki-Devel/plugin
 
 =item Nanami
 
-L<http://lineage.netgamers.jp/> etc...
+L<http://nanakochi.daiba.cx/> etc...
 
 =item PyukiWiki Developers Team
 
@@ -352,9 +357,9 @@ L<http://pyukiwiki.sourceforge.jp/>
 
 =head1 LICENSE
 
-Copyright (C) 2005-2006 by Nanami.
+Copyright (C) 2005-2011 by Nanami.
 
-Copyright (C) 2005-2006 by PyukiWiki Developers Team
+Copyright (C) 2005-2011 by PyukiWiki Developers Team
 
 License is GNU GENERAL PUBLIC LICENSE 2 and/or Artistic 1 or each later version.
 
