@@ -1,12 +1,12 @@
 ######################################################################
 # mailform.inc.pl - This is PyukiWiki, yet another Wiki clone.
-# $Id: mailform.inc.pl,v 1.6 2007/07/15 07:40:09 papu Exp $
+# $Id: mailform.inc.pl,v 1.39 2011/05/04 07:26:50 papu Exp $
 #
-# "PyukiWiki" version 0.1.7 $$
-# Author: Nanami http://lineage.netgamers.jp/
-# Copyright (C) 2004-2007 by Nekyo.
-# http://nekyo.hp.infoseek.co.jp/
-# Copyright (C) 2005-2007 PyukiWiki Developers Team
+# "PyukiWiki" version 0.1.9 $$
+# Author: Nanami http://nanakochi.daiba.cx/
+# Copyright (C) 2004-2011 by Nekyo.
+# http://nekyo.qp.land.to/
+# Copyright (C) 2005-2011 PyukiWiki Developers Team
 # http://pyukiwiki.sourceforge.jp/
 # Based on YukiWiki http://www.hyuki.com/yukiwiki/
 # Powerd by PukiWiki http://pukiwiki.sourceforge.jp/
@@ -16,8 +16,6 @@
 # modify it under the same terms as Perl itself.
 # Return:LF Code=EUC-JP 1TAB=4Spaces
 ######################################################################
-# Author: Nanami <nanami (at) daiba (dot) cx>
-######################################################################
 # v0.1.7ʹѤǤ
 #
 # v 0.0.1 - ProtoType
@@ -392,3 +390,35 @@ sub plugin_mailform_optionparse {
 }
 
 1;
+__END__
+
+=head1 NAME
+
+mailform.inc.pl - PyukiWiki Plugin
+
+=head1 AUTHOR
+
+=over 4
+
+=item Nanami
+
+L<http://nanakochi.daiba.cx/> etc...
+
+=item PyukiWiki Developers Team
+
+L<http://pyukiwiki.sourceforge.jp/>
+
+=back
+
+=head1 LICENSE
+
+Copyright (C) 2005-2011 by Nanami.
+
+Copyright (C) 2005-2011 by PyukiWiki Developers Team
+
+License is GNU GENERAL PUBLIC LICENSE 2 and/or Artistic 1 or each later version.
+
+This program is free software; you can redistribute it and/or
+modify it under the same terms as Perl itself.
+
+=cut
